import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm036p',
    templateUrl: './SNM036P.component.html',
    styleUrls: ['./SNM036P.component.css']
})

export class SNM036PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
    ) { }

    @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
    @ViewChild("dialogEdit", { static: false }) dialogEdit: any;
    @ViewChild("autoCompleteDisEdit") autoCompleteDisEdit: any;

    public currentDate: string;
    public CustomerList: any;
    public tableData: any = [];
    public JobTypeList: any = [];
    public opened: boolean = false;

    public Param = {
        CUSTOMER_CODE: null,
        CUSTOMER_NAME: null
    }

    public ParamAdd = {
        CUSTOMER_CODE: null,
        CUSTOMER_NAME: null,
        SEQ_NO: null,
        DISCOUNT_GROUP: null,
        DISCOUNT_GROUP_SHOW: null,
        EFFECTIVE_DATE: new Date(),
        DISABLE_DATE: new Date(),
        EFFECTIVE_DATE_FORMAT: null,
        DISABLE_DATE_FORMAT: null
    }

    public ParamEdit = {
        CUSTOMER_CODE: null,
        CUSTOMER_NAME: null,
        SEQ_NO: null,
        DISCOUNT_GROUP: null,
        EFFECTIVE_DATE: new Date(),
        DISABLE_DATE: new Date(),
        EFFECTIVE_DATE_FORMAT: null,
        DISABLE_DATE_FORMAT: null,
        UPDATE_BY: null,
        UPDATE_DATE: null,
        DISCOUNT_GROUP_SHOW: null
    }

    public ConfigCustomer: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Customer Code",
        SourceController: "AC",
        SourceMethodName: "SNM036P_GetCustomerAutoComplete",
        NoOfShowRecords: 50,
        MinLengthSearch: 3,
        UpperCase: false
    }

    public ConfigCustomerMaster: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Customer Code",
        SourceController: "AC",
        SourceMethodName: "SNM036P_GetCustomerMasterAutoComplete",
        NoOfShowRecords: 50,
        MinLengthSearch: 3,
        UpperCase: false
    }

    public ConfigDiscountGroup: any = {
        ColName: "LOOKUP",
        ColValue: "",
        PlaceholderText: "Select Discount Group",
        SourceController: "AC",
        SourceMethodName: "SNM036P_GetDiscountGroup",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: false
    }

    public hideCols: Array<string> = []
    CustomerCodeControl = new FormControl('', [Validators.required]);
    SEQControl = new FormControl('', [Validators.required]);


    ngOnInit() {
        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }

    Search() {
        this.tableData = []
        this.http.get("AC", "SNM036P_GetCustomerDiscountSpecial", this.Param.CUSTOMER_CODE)
            .subscribe(res => {
                this.tableData = res.Table

            })
    }

    openDialog() {
        console.log(this.ParamAdd)
        this.CustomerCodeControl.reset();
        this.SEQControl.reset();
        this.ParamAdd = this.global.ClearObject(this.ParamAdd)
        this.ParamAdd.DISCOUNT_GROUP = null
        this.ParamAdd.DISABLE_DATE = new Date();
        this.ParamAdd.EFFECTIVE_DATE = new Date();
        this.ParamAdd.SEQ_NO = null;
        this.dialogAdd.OpenDialog();
    }

    SaveAdd() {

        if (this.ParamAdd.DISABLE_DATE <= this.ParamAdd.EFFECTIVE_DATE) {
            this.modal.warning("Disable Date must be more than Effective Date", this.viewref)
        }
        else {

            this.http.get("AC", "SNM036P_CheckOverlapDate", this.FormatDate(this.ParamAdd.EFFECTIVE_DATE), this.ParamAdd.CUSTOMER_CODE, this.ParamAdd.DISCOUNT_GROUP)
                .subscribe(res => {
                    if (res.Table[0].STATUS == 'Overlap') {
                        this.modal.warning("No change to save Found overlap date", this.viewref)
                    } else {
                        this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmSave)
                    }

                })



        }

    }

    CancelAdd() {
        this.dialogAdd.Close()
    }

    ConfirmSave = () => {

        this.ParamAdd.EFFECTIVE_DATE_FORMAT = this.FormatDate(this.ParamAdd.EFFECTIVE_DATE)
        this.ParamAdd.DISABLE_DATE_FORMAT = this.FormatDate(this.ParamAdd.DISABLE_DATE)

        this.http.post('AC', 'SNM036P_Insert', this.ParamAdd)
            .subscribe(res => {

                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.Search();
                    this.ParamAdd = this.global.ClearObject(this.ParamAdd);
                    this.ParamAdd.DISCOUNT_GROUP = null;
                    this.ParamAdd.DISABLE_DATE = new Date();
                    this.ParamAdd.EFFECTIVE_DATE = new Date();
                    this.dialogAdd.Close();

                } else if (res.Table[0].STATUS == 'Duplicate') {
                    this.modal.warning('No change to save. Found duplicate record.', this.viewref);
                } else if (res.Table[0].STATUS == 'Overlap') {
                    this.modal.warning("No change to save Found overlap date", this.viewref)
                }
                else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            }, (err) => {
                this.modal.error(err.message, this.viewref);
            })
    }


    Edit(data) {
        this.CustomerCodeControl.reset();
        this.SEQControl.reset();
        this.ParamEdit = Object.assign({}, data);
        this.dialogEdit.OpenDialog()

        setTimeout(() => {
            this.autoCompleteDisEdit.textInput = this.ParamEdit.DISCOUNT_GROUP;
            this.autoCompleteDisEdit.query();
        },50)
    }

    SaveEdit() {

        if (new Date(this.ParamEdit.DISABLE_DATE) < new Date(this.ParamEdit.EFFECTIVE_DATE)) {
            this.modal.warning("Disable Date must be more than Effective Date", this.viewref)
        }
        else {
            this.http.get("AC", "SNM036P_CheckOverlapDateEdit", this.FormatDate(this.ParamEdit.EFFECTIVE_DATE), this.FormatDate(this.ParamEdit.DISABLE_DATE), this.ParamEdit.CUSTOMER_CODE, this.ParamEdit.SEQ_NO)
                .subscribe(res => {
                    console.log(res)
                    if (res.Table[0].STATUS == 'Overlap') {
                        this.modal.warning("No change to save Found overlap date", this.viewref)
                    } else {
                        this.modal.confirm("Do you want to save changed you have made?", this.viewref, this.ConfirmEdit)
                    }
                })
        }



    }

    ConfirmEdit = () => {

        this.ParamEdit.EFFECTIVE_DATE_FORMAT = this.FormatDate(this.ParamEdit.EFFECTIVE_DATE)
        this.ParamEdit.DISABLE_DATE_FORMAT = this.FormatDate(this.ParamEdit.DISABLE_DATE)

        this.http.post('AC', 'SNM036P_Update', this.ParamEdit)
            .subscribe(res => {

                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.Search();
                    this.dialogEdit.Close();
                }
                else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            }, (err) => {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            })
    }

    CancleEdit() {
        this.dialogEdit.Close();
    }


    Delete(data) {
        this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
    }

    ConfirmDelete = data => {
        this.http.post('AC', 'SNM036P_Delete', data)
            .subscribe(res => {

                if (res.Table[0].STATUS == 'Done') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);
                    this.Search();
                }
                else {
                    this.modal.error('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

    DateChange(event) {

    }

    FormatDate(date) {

        let d = new Date(date);
        let Day = d.getDate().toString();
        let NewDay = Day.toString().length < 2 ? '0' + Day.toString() : Day.toString()
        let Month = d.getMonth() + 1;
        let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
        let Year = d.getFullYear().toString();
        return Year + NewMonth + NewDay;
    }

    SetDiscountGroupAdd(evt) {
        this.ParamAdd.DISCOUNT_GROUP = evt.DISCOUNT_GROUP;
        this.ParamAdd.DISCOUNT_GROUP_SHOW = evt.LOOKUP;
    }

    SetDiscountGroup(evt) {
        this.ParamEdit.DISCOUNT_GROUP = evt.DISCOUNT_GROUP;
        this.ParamEdit.DISCOUNT_GROUP_SHOW = evt.LOOKUP;
    }

}

