import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm060p',
    templateUrl: './SNM060P.component.html',
    styleUrls: ['./SNM060P.component.css']
})

export class SNM060PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private global : Globals,
        private modal : ModalService,
        private viewref : ViewContainerRef
    ) { }
    
    @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
    @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

    public currentDate: string;
    public CustomerList: any;
    public tableData: any = [];

    public Param = {
        VAT_CODE: null,
        VAT_FLAG: null,
        TAX_FLAG: null
    }

    public ParamAdd : any = {
    }

    public ParamEdit = {
        VAT_CODE: null,
        VAT_DESC: null,
        VAT_FLAG: null,
        TAX_FLAG: null,
        TAX_RATE : null,
        ATTRIBUTE1 : null,
        ATTRIBUTE2 : null,
        UPDATE_BY : null,
        UPDATE_DATE : null
    }

    public ConfigVatCode: any = {
        ColName: "LOOK_UP_VAT_CODE",
        ColValue: "",
        PlaceholderText: "Select VatCode",
        SourceController: "wPMS",
        SourceMethodName: "GetVatCode",
        NoOfShowRecords: 50,
        MinLengthSearch: 0,
        UpperCase: false
    }

    public hideCols: Array<string> = []
    VatCodeControl = new FormControl('', [Validators.required]);

    ngOnInit() {
     
        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }


    Search(){
        this.tableData = []
        this.http.post("AC","SNM060P_GetData",this.Param)
        .subscribe(res => {       
            this.tableData = res.Table
        })
    }

    openDialog(){
        this.ParamAdd = {}
        this.VatCodeControl.reset();
        this.dialogAdd.OpenDialog();
    }

    SaveAdd(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmSave)
    }

    CancelAdd(){
        this.dialogAdd.Close()
    }

    ConfirmSave = () => {
        this.http.post('AC','SNM060P_Insert',this.ParamAdd)
        .subscribe(res =>{
           
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.ParamAdd = this.global.ClearObject(this.ParamAdd);
                this.dialogAdd.Close();

            } else if (res.Table[0].STATUS == 'Duplicate') {
                this.modal.warning('No change to save. Found duplicate record.', this.viewref);
            }
            else {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })
    }


    EditVat(data){
        this.VatCodeControl.reset();
        this.ParamEdit.VAT_CODE = data.VAT_CODE
        this.ParamEdit.VAT_DESC = data.VAT_DESC
        this.ParamEdit.VAT_FLAG = data.VAT_FLAG
        this.ParamEdit.TAX_FLAG = data.TAX_FLAG
        this.ParamEdit.TAX_RATE = data.TAX_RATE
        this.ParamEdit.ATTRIBUTE1 = data.ATTRIBUTE1
        this.ParamEdit.ATTRIBUTE2 = data.ATTRIBUTE2
        this.ParamEdit.UPDATE_BY = data.LAST_UPD_BY
        this.ParamEdit.UPDATE_DATE = data.LAST_UPD_DATE
        this.dialogEdit.OpenDialog()
    }

    SaveEdit(){
        this.modal.confirm("Do you want to save changed you have made?",this.viewref,this.ConfirmEdit)
    
    }

    ConfirmEdit = () => {

        this.http.post('AC','SNM060P_Update',this.ParamEdit)
        .subscribe(res =>{
           console.log(res)
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
                this.dialogEdit.Close();
            } 
            else {
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })
    }

    CancleEdit(){
        this.dialogEdit.Close();
    }


    Delete(data){
        this.modal.confirm("Do you want to delete record?",this.viewref, () => this.ConfirmDelete(data) )
    }

    ConfirmDelete = data => {

        this.http.post('AC','SNM060P_Delete',data)
        .subscribe(res =>{
           
            if (res.Table[0].STATUS == 'Done') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);
                this.Search();
            } 
            else {
                console.log(res)
                this.modal.error('No change to save. Something went wrong.', this.viewref);
            }
        })
      
    }


}

