import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';
@Component({
  selector: 'SNSE009M',
  templateUrl: './SNSE009M.component.html',
  styleUrls: ['./SNSE009M.component.css']
})



export class SNSE009MComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("dialogReport", { static: false }) dialogReport: any;

  public tableData: any = [];
  public params: any = {}

  public DataIsSelected: any = [];
  public selection = new SelectionModel<any>(true, []);

  ngOnInit() {
    this.params.AUTO_PRINT = 'Y'
    this.params.DP_SUM_QTY = 0;
    this.params.DP_SUM_NET = 0;
    this.params.DP_SUM_ACT = 0;
  }

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE009M_GetCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedCustomerCode(values: any) {
    this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
    this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;
    this.params.ORDER_NO = null;
    this.params.ORDER_CLASS = null;

    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
  }

  public lookupOrderNoConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE009M_GetOrderNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedOrderNo(values: any) {
    this.params.ORDER_NO = values.ORDER_NO;
    this.params.ORDER_CLASS = values.ORDER_CLASS;
    this.params.ORDER_DATE = values.ORDER_DATE;
    this.params.LAST_UPD_DATE = values.LAST_UPD_DATE;
    this.params.LAST_UPD_NAME = values.LAST_UPD_NAME;

    this.params.ORDER_NO_FROM = values.ORDER_NO;
    this.params.ORDER_NO_TO = values.ORDER_NO;

    if (values.CUSTOMER_CODE) {
      this.params.CUSTOMER_CODE = values.CUSTOMER_CODE;
      this.params.CUSTOMER_NAME = values.CUSTOMER_NAME;

      this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
      this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    }
    this.Search();
  }

  public lookupOrderNoRptFromConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE009M_GetOrderNoRptFrom",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupOrderNoRptToConfig: any = {
    ColName: "LOOKUP_ORDER_NO",
    PlaceholderText: "Select Order No",
    SourceController: "SL",
    SourceMethodName: "SNSE009M_GetOrderNoRptTo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NO",
    PlaceholderText: "Select Part No",
    SourceController: "SL",
    SourceMethodName: "SNSE009M_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SelectedCustomerFrom(event) {
    this.params.CUSTOMER_CODE_FROM = event.CUSTOMER_CODE
    this.params.ORDER_NO_FROM = null;
  }

  public SelectedCustomerTo(event) {
    this.params.CUSTOMER_CODE_TO = event.CUSTOMER_CODE
    this.params.ORDER_NO_TO = null;
  }

  public SelectedOrderNoFrom(event) {
    this.params.ORDER_NO_FROM = event.ORDER_NO;
  }

  public SelectedOrderNoTo(event) {
    this.params.ORDER_NO_TO = event.ORDER_NO;
  }

  public SetSelectedPartNo(event,data) {
    data.ORDER_PART_NO = event.PART_NO;
    data.ORDER_PART_NAME = event.PART_NAME;
  }

  private Search = () => {
    this.tableData = [];
    this.Http.post('SL', 'SNSE009M_getData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      });
  }

  public isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  public Toggle() {
    if (this.isAllSelected()) {
      this.selection.clear()
      this.tableData.map(x => {
        this.DataIsSelected = [];
      })
    } else {
      this.tableData.forEach(row => this.selection.select(row));
      this.DataIsSelected = [];
      this.tableData.map(x => {
        this.DataIsSelected.push(x);
      })
    }
  }

  public CheckboxChange(event, data) {
    if (event.checked) {
      this.DataIsSelected.push(data);
      this.params.DP_SUM_QTY += data.ORDER_QTY;
      this.params.DP_SUM_NET += data.NET_AMT_B;
      this.params.DP_SUM_ACT += data.DP_ACT_AMT;
    }
    else {
      this.DataIsSelected.splice(this.DataIsSelected.indexOf(data), 1);
      this.params.DP_SUM_QTY -= data.ORDER_QTY;
      this.params.DP_SUM_NET -= data.NET_AMT_B;
      this.params.DP_SUM_ACT -= data.DP_ACT_AMT;
    }
  }


  ConfirmUpdate() {
    this.modal.confirm('Do you want to update order status', this.viewref, this.Update)
  }

  Update = () => {
  };

  public OpenReport() {
    this.dialogReport.OpenDialog();
  }

  public CloseReport() {
    this.dialogReport.Close();
  }

  public GoToReport() {
    this.global.GoToReport("PMS_RPT_SALES_SNSE009R_P",
      {
        P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
        P_CUST_CODE_FROM: this.params.CUSTOMER_CODE_FROM,
        P_CUST_CODE_TO: this.params.CUSTOMER_CODE_TO,
        P_ORDER_NO_FROM: this.params.ORDER_NO_FROM,
        P_ORDER_NO_TO: this.params.ORDER_NO_TO,
      });
  }

  public CheckConfirm(event) {
    if (event.checked) {
      this.params.CHK_CONF = 'Y';
    }
    else {
      this.params.CHK_CONF = 'N';
    }
  }

  public CheckGPR() {
    if (this.tableData.length > 0) {
      this.DataIsSelected = [];
      this.selection.clear()
      this.params.DP_SUM_QTY = 0;
      this.params.DP_SUM_NET = 0;
      this.params.DP_SUM_ACT = 0;
      this.tableData.forEach((e) => {
        if (e.DP_GPR < 0 && (e.STATUS_CODE != 'A' || 'B' || 'C' || 'L' || '50')) {
          e.CB_CANCEL = 'C'
          this.DataIsSelected.push(e);
          this.selection.select(e)
          this.params.DP_SUM_QTY += e.ORDER_QTY;
          this.params.DP_SUM_NET += e.NET_AMT_B;
          this.params.DP_SUM_ACT += e.DP_ACT_AMT;
        }
      });
    }
  }
}
