import { Component, OnInit, AfterViewInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef, OnChanges } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';
import { MatTableDataSource } from '@angular/material/table';
import { AutoCompleteQueryComponent } from '../../../components/shared/auto-complete-query/auto-complete-query.component';


@Component({
  selector: 'snsq01e_upload',
  templateUrl: './SNSQ01E_UPLOAD.component.html',
  styleUrls: ['./SNSQ01E_UPLOAD.component.css']
})

export class SNSQ01E_UPLOADComponent implements OnInit {
  public isSaved: boolean = false;
  public isSavedList: boolean = false;
  public params: any = {};

  @ViewChild("dialog", { static: false }) dialog: any;
  private data: Array<any> = [];
  public filteredData: Array<any> = [];
  private Success: boolean = true;
  public CounterItem: number = 0;
  private origin: string = window.location.protocol + "//" + window.location.hostname + ":8090";
  public files: any = [];
  public FileName: string = "";
  public ListLog: any = [];
  @ViewChild("dialogLog", { static: false }) dialogLog: any;

  @Output() datacallback = new EventEmitter<string>();
  @Input("partNo") partNo: string;


  constructor(
    private Http: HttpService,
    private router: Router,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  @ViewChild("autoCompletePartNo", { static: false }) autoCompletePartNo: AutoCompleteQueryComponent;

  public DataUploadList: any;

  public lookupPartNoConfig: any = {
    ColName: "LOOKUP_PART_NAME",
    PlaceholderText: "Select Part No.",
    SourceController: "SL",
    SourceMethodName: "SNSQ01E_GetPartNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 1,
    UpperCase: true
  }

  ngOnInit() {
    this.params.PART_NO = this.partNo;
    if (this.partNo) {
      this.params.PART_NO = this.partNo;
    }
    else {
      this.params.PART_NO = null;
    }
  }

  ngAfterViewInit() {
    if (this.params.PART_NO) {
      this.autoCompletePartNo.textInput = this.params.PART_NO;
      this.autoCompletePartNo.query();
    }
  }


  public SetSelectedPartNo(value: any) {
    this.params.PART_NO = value.PART_NO;
    this.params.PART_NAME_EN = value.PART_NAME_EN;
    this.params.PART_NAME_TH = value.PART_NAME_TH;
    this.params.DIU_FLAG = value.DIU_FLAG;
    this.params.TARIFF_CODE = value.TARIFF_CODE;
    this.params.LAST_UPD_NAME = value.LAST_UPD_BY;
    this.params.LAST_UPD_DATE = value.LAST_UPD_DATE;
    this.isSaved = false;
  }

  public lookupTariffCodeConfig: any = {
    ColName: "TARIFF_CODE",
    PlaceholderText: "Select Tariff Code",
    SourceController: "SL",
    SourceMethodName: "SNSQ01E_GetTariffCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetSelectedTariffCode(value: any) {
    this.params.NEW_TARIFF_CODE = value.TARIFF_CODE;
  }

  flagCheck(event: any) {
    if (event.checked) {
      this.params.NEW_DIU_FLAG = 'Y'
    }
    else {
      this.params.NEW_DIU_FLAG = 'N'
    }
  }

  //SAVE BY PART
  ConfirmSave() {
    if (this.params.NEW_TARIFF_CODE) {
      this.modal.confirm('Do you want to update on this data?', this.viewref, this.Save)
    }
    else {
      this.modal.warning('Plese fill New Tariff Code', this.viewref)
    }
  }

  Save = () => {
    this.Http.post('SL', 'SNSQ01E_Save', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Done.', this.viewref);
          this.isSaved = true;
          this.params.DIU_FLAG = this.params.NEW_DIU_FLAG;
          this.params.TARIFF_CODE = this.params.NEW_TARIFF_CODE;
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  ConfirmUpdateSO () {
    this.modal.confirm('Do you want to update?', this.viewref, this.UpdateSO)
  }

  UpdateSO = () => {
    this.Http.post('SL', 'SNSQ01E_UpdateSO', this.params)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Update Completed.', this.viewref);
          this.isSaved = false;
          this.params.NEW_TARIFF_CODE = null;
          this.params.NEW_DIU_FLAG = 'N'
          this.datacallback.emit('DONE');
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }


  //SAVE BY UPLOAD
  ConfirmSaveList() {
    if (this.DataUploadList) {
      var err = null;
      this.ListLog = [];
      this.DataUploadList.forEach((e, index) => {
        var index1 = index + 1;
        if (e.REMARK) {
          this.ListLog.push('Error at Row ' + index1 + ' please re-check your column Message on row.')
          err = 'Y'
        }
      });
      if (!err) {
        this.modal.confirm('Do you want to update on this data?', this.viewref, this.SaveList)
      }
      else {
        this.dialogLog.OpenDialog();
      }
    }
    else {
      this.modal.warning('Please upload data first!!', this.viewref)
    }
  }

  SaveList = () => {
    this.Http.post('SL', 'SNSQ01E_SaveList', this.DataUploadList)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Save completed.', this.viewref);
          this.isSavedList = true;
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  ConfirmUpdateSOList = () => {
    this.modal.confirm('Do you want to update?', this.viewref, this.UpdateSOList)
  }

  UpdateSOList = () => {
    this.Http.post('SL', 'SNSQ01E_UpdateSOList', this.DataUploadList)
      .subscribe(res => {
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Update Completed.', this.viewref);
          this.DataUploadList = null;
          this.isSavedList = false;
          this.datacallback.emit('DONE');
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }


  //UPLOAD
  OnFileSelect(fileInput) {
    this.files = fileInput.target.files;
    this.FileName = this.files[0].name;
  }

  DownloadTemplate() {
    let link = "assets/templates/Maintenance_Tariffcode_Upload_Template.xlsx"
    window.open(link, '_blank')
  }

  UpLoad() {
    if (this.files.length == 0) {
      this.modal.error('Please Open xlsx File First...', this.viewref)
    } else {
      this.data = []
      let formData = new FormData();
      formData.append('file', this.files[0]);

      this.Http.postFile('SL', 'SNSQ01E_Upload', formData)
        .subscribe(res => {
          this.DataUploadList = null;
          this.Http.get('SL', 'SNSQ01E_GetTempData')
            .subscribe(res => {
              this.DataUploadList = res.Table;
              if (this.DataUploadList.length > 0) {
                this.DataUploadList.forEach((e, index) => {
                  e.NO = index + 1;
                });
              }
            });
        });
    }
  }

  Close() {
    this.dialogLog.Close();
    this.ListLog = [];
  }
}
