import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { MatTableDataSource } from '@angular/material/table';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';

@Component({
    selector: 'snm030p',
    templateUrl: './SNM030P.component.html',
    styleUrls: ['./SNM030P.component.css']
})



export class SNM030PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private modal: ModalService,
        private viewlef: ViewContainerRef,
        private route: ActivatedRoute,
        private global: Globals
    ) {
    }

    public data: any = [];
    public VENDOR_CODE: any;
    public VENDOR_NAME: any;
    public displayedColumns: string[] = ['fulfillment', 'safety'];
    public showNoRecord: boolean = false;


    @ViewChild("dialog", { static: false }) dialog: any;
    @ViewChild("dialogAdd", { static: false }) dialogAdd: any;
    @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

    public selection = new SelectionModel<any>(false, null);
    public ConfigFulfill: any = {
        ColName: "FULFILL_RATE",
        ColValue: "FULFILL_RATE",
        PlaceholderText: "Select Fulfillment Rate",
        SourceController: "IC",
        SourceMethodName: "SNM030P_GetMasterFulfill",
        NoOfShowRecords: 30,
        MinLengthSearch: 1
    }

    public ConfigSafeAllow: any = {
        ColName: "SAFE_ALLOWANCE",
        ColValue: "SAFE_ALLOWANCE",
        PlaceholderText: "Select Safety Allowance",
        SourceController: "IC",
        SourceMethodName: "SNM030P_GetMasterSafeAllowance",
        NoOfShowRecords: 30,
        MinLengthSearch: 1
    }

    Param = {
        Fulfillment: null,
        SafetyAllowance: null
    }

    public FromData: any = {
        Fulfillment: null,
        SafetyAllowance: null,
        UpDateBy: null,
        UpdateDate: null
    }


    public AddData: any = {
        Fulfillment: 0,
        SafetyAllowance: 1,
    }

    public DeleteData: any = {
        Fulfillment: 0,
        SafetyAllowance: 1,
    }

    public hideCols: Array<string> = []


    ngOnInit() {
        this.GetFulfillRate();

        this.global.GetRoleDetail().CHG === "N" ? this.hideCols.push("EDIT") : null;
        this.global.GetRoleDetail().DEL === "N" ? this.hideCols.push("DELETE") : null;
    }


    GetFulfillRate() {
        this.data = [];
        this.http.post('IC', 'SNM030P_GetFulfillRate', this.Param)
            .subscribe(res => {
                this.data = res.Table;
            })
    }

    applyFilter(filterValue: string) {
        this.data = this.data.filter(x => filterValue.indexOf(x.FULFILL_RATE) > -1)
    }


    OK() {
        this.dialog.Close();
        let data = this.selection.selected[0];
        this.FromData.Fulfillment = data.FULFILL_RATE;
        this.FromData.SafetyAllowance = data.SAFE_ALLOWANCE;
        this.FromData.UpDateBy = data.LAST_UPD_BY;
        this.FromData.UpdateDate = data.LAST_UPD_DATE;
    }

    Cancel() {
        this.dialog.Close();
    }

    AddNew() {
        this.AddData = {
            Fulfillment: 0,
            SafetyAllowance: 1,
        }

        this.dialogAdd.OpenDialog();
    }

    SaveAdd() {

        if (this.AddData.Fulfillment > 100) {
            this.modal.warning('Must be in range 0.00 to 100.00', this.viewlef)
        } else if (this.AddData.SafetyAllowance > 10) {
            this.modal.warning('Field must be of form 0.00 to 9.99', this.viewlef)
        } else {

            this.modal.confirm('Do you want to save changed you have made?', this.viewlef, this.ConfirmSaveAdd)
        }
    }

    ConfirmSaveAdd = () => {

        this.http.post('IC', 'SNM030P_InsertFulfillment', this.AddData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewlef, this.CancelAdd)
                    this.GetFulfillRate();
                } else if (res.Table[0].STATUS == 'DUPPLICATE') {
                    this.modal.warning('No change to save. Found dupplicate record.', this.viewlef)
                } else {
                    this.modal.error('No change to save. Something went wrong.', this.viewlef)
                }
            })
    }

    CancelAdd = () => {
        this.dialogAdd.Close();
    }

    Edit(data) {

        this.FromData.Fulfillment = data.FULFILL_RATE;
        this.FromData.SafetyAllowance = data.SAFE_ALLOWANCE;
        this.FromData.UpDateBy = data.LAST_UPD_BY;
        this.FromData.UpdateDate = data.LAST_UPD_DATE;
        this.dialogEdit.OpenDialog();
    }

    SaveEdit() {
        if (this.FromData.Fulfillment > 100) {
            this.modal.warning('Must be in range 0.00 to 100.00', this.viewlef)
        } else if (this.FromData.SafetyAllowance > 10) {
            this.modal.warning('Field must be of form 0.00 to 9.99', this.viewlef)
        } else {

            this.modal.confirm('Do you want to save changed you have made?', this.viewlef, this.ConfirmEdit)
        }
    }

    ConfirmEdit = () => {

        this.http.post('IC', 'SNM030P_EditFulfillment', this.FromData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewlef)
                    this.GetFulfillRate();
                    this.dialogEdit.Close();
                } else {
                    this.modal.error('No change to save. Something went wrong.', this.viewlef)
                }
            })
    }


    Delete(data) {
        this.DeleteData.Fulfillment = data.FULFILL_RATE;
        this.DeleteData.SafetyAllowance = data.SAFE_ALLOWANCE;
        this.modal.confirm('Do you want to delete record?', this.viewlef, this.ConfirmDelete)
    }

    ConfirmDelete = () => {
      
        this.http.post('IC', 'SNM030P_DeleteFulfillment', this.DeleteData)
            .subscribe(res => {

                if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewlef)
                    this.GetFulfillRate();
                } else {
                    this.modal.error('No change to save. Something went wrong.', this.viewlef)
                }
            })
    }


}

