import { Component, OnInit, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { FormGroup, FormControl, Validators } from '@angular/forms'
import { Router, ActivatedRoute } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from 'src/app/core/global';

@Component({
  selector: 'snm107p',
  templateUrl: './SNM107P.component.html',
  styleUrls: ['./SNM107P.component.css']
})



export class SNM107PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
  ) {
  }

  public data: any = [];
  public RawdataLtOn: any = [];
  public RawdataLtOff: any = [];
  public SelectList: any;
  public CheckRecord: boolean = false;
  public selection = new SelectionModel<any>(true, []);
  public Update: any = [];
  public ConfigVendor: any = {
    ColName: "LOOKUP_VENDOR_NAME",
    ColValue: "",
    PlaceholderText: "Select Vendor",
    SourceController: "wPMS",
    SourceMethodName: "GetVendorCode",
    NoOfShowRecords: 100,
    MinLengthSearch: 1,
    UpperCase: true
  }


  public ConfigPart: any = {
    ColName: "LOOKUP_PART_NAME",
    ColValue: "PART_NO",
    PlaceholderText: "Select Part No.",
    SourceController: "wPMS",
    SourceMethodName: "GetPartNo",
    NoOfShowRecords: 100,
    MinLengthSearch: 5
  }

  public Criterai = {
    VENDOR_CODE: null,
    PART_NO: '',
    ONLY_EXIST: 'N'
  }

  public rateControl: any;

  ngOnInit() {
    this.rateControl = new FormControl("", [Validators.max(10), Validators.min(0)])
  }

  Search() {

    this.Criterai.ONLY_EXIST = this.CheckRecord == true ? 'Y' : 'N'

    if (!this.Criterai.VENDOR_CODE && !this.Criterai.PART_NO && this.Criterai.ONLY_EXIST == 'N') {

      this.modal.warning('Please input either [Vendor Code] or [Part No] or [Only updated record]!', this.viewref)

    } else if (!this.Criterai.VENDOR_CODE && this.Criterai.PART_NO.length < 5 && this.Criterai.ONLY_EXIST == 'N') {

      this.modal.warning('Please input [Part No] atleast 5 digit!', this.viewref)

    } else {
      this.GetData();
    }

  }

  GetData() {
    this.data = [];
    this.http.post("IC", "SNM107P_Getdata", JSON.stringify(this.Criterai))
      .subscribe(result => {
        this.RawdataLtOn = cloneDeep(result.Table);
        this.RawdataLtOff = cloneDeep(result.Table);
        this.data = result.Table
        this.selection.clear();
      })
  }


  Save() {

    if (this.selection.selected.length == 0) {
      this.modal.info('No change to save', this.viewref);
    } else {
      this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Commit)
    }

  }

  Commit = () => {

    this.http.post('IC', 'SNM107P_Save', this.selection.selected)
      .subscribe(res => {
        if (res === 'DONE') {
          this.modal.info('Transaction complete: ' + this.selection.selected.length + ' record applied and saved.', this.viewref);
          this.selection.clear();
          this.GetData();
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })

  }


  Delete() {
    if (this.selection.selected.length == 0) {
      this.modal.info('No change to delete', this.viewref);
    } else {
      this.modal.confirm('Do you want to delete record?', this.viewref, this.CommitDelete)
    }
  }

  CommitDelete = () => {

    this.http.post('IC', 'SNM107P_Delete', this.selection.selected)
      .subscribe(res => {
        if (res === 'DONE') {
          this.modal.info('Transaction complete: ' + this.selection.selected.length + ' record applied and saved.', this.viewref);
          this.selection.clear();
          this.GetData()
        } else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }
      })
  }

  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.data.filter(x => (x.PART_LT_ON && x.PART_LT_OFF)).length;
    return numSelected === numRows;
  }

  Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.data.forEach(row => {
        if (row.PART_LT_ON && row.PART_LT_OFF) {
          this.selection.select(row)
        }
      });
  }

  SelectedVendor(event) {
    this.Criterai.VENDOR_CODE = event.VENDOR_CODE
  }

  LtOn(event, row, data) {

    let clonedata = cloneDeep(this.RawdataLtOn);
    if (event.target.valueAsNumber > 9.9) {

      let index = this.data.indexOf(row)
      this.data[index] = clonedata[index];
      this.data = this.data.slice();
    }

  }

  LtOff(event, row, data) {

    let clonedata = cloneDeep(this.RawdataLtOff);
    if (event.target.valueAsNumber > 9.9) {

      let index = this.data.indexOf(row)
      this.data[index] = clonedata[index];
      this.data = this.data.slice();
    }

  }

  ValidateCheckbox(event) {
    this.modal.info('Leadtime must be input!', this.viewref)
    return false;
  }



}

