import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { DomSanitizer } from '@angular/platform-browser';

@Component({
  selector: 'snpj005_drg',
  templateUrl: './snpj005_drg.component.html',
  styleUrls: ['./snpj005_drg.component.css'],
  providers: [Globals]
})


export class SNPJ005_DRGComponent implements OnInit {

  public filePath: string;
  public fileList: any = {};
  public headerUrl: string;
  public detailUrl: string;

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private route: ActivatedRoute,
    public global: Globals,
    public domsanitizer: DomSanitizer
  ) { 

  }


  ngOnInit() {
    this.GetFilePath();
  }

  GetFilePath() {
    this.http.get("IC", "SNPJ005_DRG_GetFilePath")
      .subscribe((result: any) => {
        this.filePath = result.Table[0]["TO_FILE_NAME"].toString();
      })
  }

  BeginProcess() {
    this.modal.confirm("Are you sure to begin the process?", this.viewref,
      () => {
        this.http.post("IC", "SNPJ005_DRG_BeginProcess", {})
        .subscribe(result => {
          this.fileList = result;
          this.headerUrl = "data:text/plain;charset=utf-8;base64," + result.Header.file;
          this.detailUrl = "data:text/plain;charset=utf-8;base64," + result.Detail.file;
          this.modal.info("Run process completed.", this.viewref);
        }, err => {
          this.modal.error(err.error, this.viewref);
        })
      }, () => {})
  }
}

