import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { AuthDecode } from 'src/app/core/auth-decode.service';
import { ModalService } from '../../../core/modal.service';
import { Globals } from '../../../core/global';


@Component({
  selector: 'snm081p',
  templateUrl: './snm081p.component.html',
  styleUrls: ['./snm081p.component.css']
})



export class SNM081PComponent implements OnInit {

  public params = {
    ORIGIN_CODE: null,
    ORIGIN_NAME: null
  }

  public Data: any = {
    COMPANY_CODE: null,
    ORIGIN_CODE: null,
    ORIGIN_NAME: null,
    ORIGIN_NAME2: null,
    CREATE_BY: null,
    CREATE_DATE: null,
    CREATE_BY_NAME: null,
    LAST_UPD_PGM: null,
    LAST_IP_ADDR: null,
    LAST_UPD_BY: null,
    LAST_UPD_DATE: null,
    UPDATE_BY_NAME: null,
  };

  constructor(
    private http: HttpService,
    private router: Router,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private auth: AuthDecode,
    private global: Globals
  ) { }

  @ViewChild("dialogMain", { static: false }) dialogMain: any;
  @ViewChild("dialogEdit", { static: false }) dialogEdit: any;

  public tableData: any = [];
  public FrmTitle: any;
  public IsEdit: any = true;

  public lookupOriginCodeConfig: any = {
    ColName: "LOOKUP_ORIGIN_CODE",
    PlaceholderText: "Select Origin Code",
    SourceController: "IC",
    SourceMethodName: "SNM081P_GetOriginCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  SetSelectedOriginCode(value: any) {
    this.params.ORIGIN_CODE = value.ORIGIN_CODE;
    this.params.ORIGIN_NAME = value.ORIGIN_NAME;
  };

  ngOnInit() {
    this.Search()
  }

  Search = () => {
    this.http.post('IC', 'SNM081P_GetData', this.params)
      .subscribe(res => {
        this.tableData = res.Table;
      })
  }

  InitData() {
    this.Data = {};
  }

  CreateClick() {
    this.FrmTitle = "New Origin Code";
    this.InitData();
    this.IsEdit = false;
    this.dialogMain.OpenDialog();
  }

  EditClick(row) {
    this.FrmTitle = "Edit Origin Code";
    this.InitData();
    this.Data = row;
    this.IsEdit = true;
    this.dialogEdit.OpenDialog();
  }

  ConfirmDelete(row) {
    this.Data = row;
    this.modal.confirm("Do you want to delete this record?", this.viewref, this.Delete);
  }

  Delete = () => {
    this.http.post('IC', 'SNM081P_Delete', this.Data)
      .subscribe(res => {
        if (res.Table[0].STATUS === "DONE") {
          this.modal.info('Transaction complete: 1 record deleted.', this.viewref);
          this.Search();
          this.params.ORIGIN_CODE = null;
          this.params.ORIGIN_NAME = null;
        }
      });
  }

  ConfirmSave() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.Save)
  }

  Save = () => {
    this.http.post('IC', 'SNM081P_Update', this.Data)
      .subscribe(res => {
        console.log(res)
        if (res == 'Done') {
          this.InitData();
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.dialogMain.Close();
          this.Search();
        }
        else {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })
  }

  CancelMain() {
    this.InitData();
    this.dialogMain.Close();
  }
  CancelEdit() {
    this.InitData();
    this.dialogEdit.Close();
  }
}

