import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { Globals } from '../../../core/global';
import { ModalService } from '../../../core/modal.service';
import { MatDatepicker } from '@angular/material/datepicker';
import * as moment from 'moment';

@Component({
    selector: 'snpr019',
    templateUrl: './snpr019.component.html',
    styleUrls: ['./snpr019.component.css']
})

export class SNPR019Component implements OnInit {
    constructor(
        private http: HttpService,
        private router: Router,
        private global: Globals,
        private modal: ModalService,
        private viewref: ViewContainerRef
    ) { }
    selection = new SelectionModel<any>(true, []);
    public VENDOR_CODE_FROM: any;
    public VENDOR_CODE_TO: any;
    public INVOICE_NO_FROM: any;
    public INVOICE_NO_TO: any;
    private fileList : any = [];


    public VendorConfig: any = {
        ColName: "VENDOR_TEXT",
        ColValue: "VENDOR_CODE",
        PlaceholderText: "Select Vendor Code",
        SourceController: "IC",
        SourceMethodName: "SNPR019_FindFVendor",
        NoOfShowRecords: 50,
        MinLengthSearch: 2,
        UpperCase: true
    }
    public InvoiceConfig: any = {
        ColName: "INVOICE_NO",
        ColValue: "INVOICE_NO",
        PlaceholderText: "Select Invoice No.",
        SourceController: "IC",
        SourceMethodName: "SNPR019_FindFInvoice",
        NoOfShowRecords: 50,
        MinLengthSearch: 3
    }

    public list: any = [
        { ID: "check_sum", TEXT: "Summary", reportName: 'PMS_RPT_IC_SNPR019R1' },
        { ID: "check_list", TEXT: "Listing", reportName: 'PMS_RPT_IC_SNPR019R2' },
        { ID: "check_detail", TEXT: "Detail", reportName: 'PMS_RPT_IC_SNPR019R3' },
        { ID: "check_new", TEXT: "Newly Priced", reportName: 'PMS_RPT_IC_SNPR019R4' }
    ]

    public ListDataReportCondition: any = {
        COMPANY_CODE: null,
        VENDOR_CODE_FROM: null,
        VENDOR_CODE_TO: null,
        INVOICE_NO_FROM: null,
        INVOICE_NO_TO: null,
        SHIPPED_DATE_FROM: null,
        SHIPPED_DATE_TO: null,
    };

    public selectedProducts: string[] = [];

    ngOnInit() {
        this.ListDataReportCondition.SHIPPED_DATE_FROM = moment();
        this.ListDataReportCondition.SHIPPED_DATE_TO = moment();
    }

    SetFVendor(FVendorCode) {
        this.ListDataReportCondition.VENDOR_CODE_FROM = FVendorCode;
    }
    SetLVendor(TVendorCode) {
        this.ListDataReportCondition.VENDOR_CODE_TO = TVendorCode;
    }
    SetFInvoice(FInvoiceNo) {
        this.ListDataReportCondition.INVOICE_NO_FROM = FInvoiceNo;
    }
    SetLInvoice(TInvoiceNo) {
        this.ListDataReportCondition.INVOICE_NO_TO = TInvoiceNo;
    }

    GoToReport() {
        let countReport = 0;
        let reportParams = {
            P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
            P_VENDOR_CODE_FROM: this.ListDataReportCondition.VENDOR_CODE_FROM,
            P_VENDOR_CODE_TO: this.ListDataReportCondition.VENDOR_CODE_TO,
            P_INVOICE_NO_FROM: this.ListDataReportCondition.INVOICE_NO_FROM,
            P_INVOICE_NO_TO: this.ListDataReportCondition.INVOICE_NO_TO,
            P_SHIPPED_DATE_FROM: this.SetformatDate(this.ListDataReportCondition.SHIPPED_DATE_FROM),
            P_SHIPPED_DATE_TO: this.SetformatDate(this.ListDataReportCondition.SHIPPED_DATE_TO)
        }

        this.fileList = [];

        this.selection.selected.forEach(v => {
            countReport++;

            this.http.getParams("IC", ["SNPR019_GenerateReport", v.reportName], reportParams)
                .subscribe(result => {

                    this.fileList.push({
                        file_path : result,
                        file_name : v.reportName + "." + "PDF"
                    })

                    countReport--;
                    if (countReport === 0) {
                        this.modal.info("Generate reports completed. <br/>You can save the result or access to report shared folder to download your reports.", this.viewref);
                        this.DownloadFile();
                    }
                })
        })
    }

    DownloadFile() {
        this.http.DownloadMultipleFilesAsZip("IC","SNPR019_Download",this.fileList)
        .subscribe(res =>{
            this.WriteFile(res);
        })
    }

    CheckExportDataCondition() {
        this.ListDataReportCondition.VENDOR_CODE_FROM = this.ListDataReportCondition.VENDOR_CODE_FROM || this.ListDataReportCondition.VENDOR_CODE_TO;
        this.ListDataReportCondition.VENDOR_CODE_TO = this.ListDataReportCondition.VENDOR_CODE_TO || this.ListDataReportCondition.VENDOR_CODE_FROM;
        this.ListDataReportCondition.INVOICE_NO_FROM = this.ListDataReportCondition.INVOICE_NO_FROM || this.ListDataReportCondition.INVOICE_NO_TO;
        this.ListDataReportCondition.INVOICE_NO_TO = this.ListDataReportCondition.INVOICE_NO_TO || this.ListDataReportCondition.INVOICE_NO_FROM;
    }

    ExportDataBO() {

        if (this.selection.selected.length == 0) {
            this.modal.warning('Please select a report to view.', this.viewref);
        } else {
            this.CheckExportDataCondition();
            this.http.post("IC", "SNPR019_TransData", this.ListDataReportCondition)
                .subscribe(() => {
                    this.GoToReport();
                })
        }
    }

    SetformatDate(date) {
        let d = new Date(date)
        let day = d.getDate();
        let month = d.getMonth() + 1;
        let newmonth = month.toString().length < 2 ? 0 + month.toString() : month.toString();
        let year = d.getFullYear();

        return day + '-' + newmonth + '-' + year;
    }

    OpendateFromPopup(datepicker: MatDatepicker<any>) {
        datepicker.open();
    }

    OpendateToPopup(datepicker: MatDatepicker<any>) {
        datepicker.open();
    }

    WriteFile(res) {
        let date: string = moment().format('YYYYMMDD');
        var blob = new Blob([res], { type: "application/octet-stream" });
        var fileURL = URL.createObjectURL(blob);
        var a = document.createElement('a');
        a.href = fileURL;
        a.target = '_blank';
        a.download = "SNPR019_" + date + ".zip";
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
    }

}

