import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Globals } from 'src/app/core/global';
import { ModalService } from 'src/app/core/modal.service';
import * as moment from 'moment';


@Component({
  selector: 'snse044N',
  templateUrl: './SNSE044N.component.html',
  styleUrls: ['./SNSE044N.component.css']
})

export class SNSE044NComponent implements OnInit {

  constructor(
    private Http: HttpService,
    private global: Globals,
    private modal: ModalService,
    private viewref: ViewContainerRef
  ) { }

  public params: any = {};

  public tableData: any = [];

  public lookupCustomerCodeConfig: any = {
    ColName: "LOOKUP_CUSTOMER_CODE",
    PlaceholderText: "Select Customer Code",
    SourceController: "SL",
    SourceMethodName: "SNSE044N_getCustomerCode",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public lookupInvoiceDateConfig: any = {
    ColName: "DOCUMENT_DATE",
    PlaceholderText: "Select Invoice Date",
    SourceController: "SL",
    SourceMethodName: "SNSE044N_getInvoiceDate",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public lookupDocNoConfig: any = {
    ColName: "LOOKUP_DOCUMENT_NO",
    PlaceholderText: "Select Doc No.",
    SourceController: "SL",
    SourceMethodName: "SNSE044N_getDocNo",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    SourceParams: {
      DATA: this.params
    },
    UpperCase: true
  }

  public SetSelectedCustomerCodeFrom(values: any) {
    this.params.DSP_CUSTOMER_CODE_FROM = values.LOOKUP_CUSTOMER_CODE
    this.params.CUSTOMER_CODE_FROM = values.CUSTOMER_CODE;
    this.clearInput()

  }

  public SetSelectedCustomerCodeTo(values: any) {
    this.params.DSP_CUSTOMER_CODE_TO = values.LOOKUP_CUSTOMER_CODE
    this.params.CUSTOMER_CODE_TO = values.CUSTOMER_CODE;
    this.clearInput()
  }

  public SetSelectedInvoiceDateFrom(values: any) {
    this.params.INVOICE_DATE_FROM = values.DOCUMENT_DATE;
  }

  public SetSelectedInvoiceDateTo(values: any) {
    this.params.INVOICE_DATE_TO = values.DOCUMENT_DATE;
  }

  public SetSelectedDocNoFrom(values: any) {
    this.params.DOC_NO_FROM = values.DOCUMENT_NO;
  }

  public SetSelectedDocNoTo(values: any) {
    this.params.DOC_NO_TO = values.DOCUMENT_NO;
  }

  ngOnInit() {
    this.params.SENT_BY = 'A'
    this.params.CHK_PRN_MITH = 'Y'
    this.getFileName();
    this.getDocType();
  }

  private clearInput() {
    this.params.INVOICE_DATE_FROM = null;
    this.params.INVOICE_DATE_TO = null;
    this.params.DOC_NO_FROM = null;
    this.params.DOC_NO_TO = null;
  }

  private getFileName() {
    this.Http.get('SL', 'SNSE44N_getFileName')
      .subscribe(res => {
        this.params.TO_PATH = res.Table[0].TO_FILE_NAME;
      });
  }

  private getDocType() {
    this.Http.get('SL', 'SNSE44N_getDocType')
      .subscribe(res => {
        this.params.DOC_TYPE = res.Table[0].DOCUMENT_TYPE;
      });
  }

  public getData() {
    if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
      this.tableData = [];
      this.Http.post('SL', 'SNSE044N_getData', this.params)
        .subscribe(res => {
          this.tableData = res.Table;
          if (res.Table.length > 0) {
            this.ExportExcel()
          }
        });
    }
    else {
      this.modal.warning('Please fill all data for Generate .CSV!!', this.viewref)
    }
  }

  private ExportExcel() {
    this.Http.Download('SL', "SNSE044N_ExportExcel", JSON.stringify(this.tableData))
      .subscribe(res => {
        if (res) {
          this.WriteContents(res)
        } else {
          this.modal.error('Download not complete', this.viewref)
        }
      });
  }

  WriteContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSE044N" + ".csv";
    a.click();
  }

  public OpenReport(type) {
    if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
      if (type == 1) { //REPORT
        this.global.GoToReport("PMS_RPT_SALES_SNSE044R_N", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_DOC_DATE_S: moment(this.params.INVOICE_DATE_FROM, "DD-MM-YYYY").format('DD-MMM-YY'),
          P_DOC_DATE_E: moment(this.params.INVOICE_DATE_TO, "DD-MM-YYYY").format('DD-MMM-YY'),
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SENT_BY: this.params.SENT_BY
        })
      }
      else if (type == 2) { //PRINT CASE MASK
        this.global.GoToReport("PMS_RPT_SALES_SNSE044R_NCM", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SHOW_ORIGIN: this.params.CHK_PRN_MITH
        })
      }
      else if (type == 3) { //ATTACHED CASE MASK
        this.global.GoToReport("PMS_RPT_SALES_SNSE044R_NACM", {
          P_COMPANY_CODE: this.global.GetTokenDetail("ssComCode"),
          P_DOC_TYPE: this.params.DOC_TYPE,
          P_DOC_NO_S: this.params.DOC_NO_FROM,
          P_DOC_NO_E: this.params.DOC_NO_TO,
          P_DOC_DATE_S: moment(this.params.INVOICE_DATE_FROM, "DD-MM-YYYY").format('DD-MMM-YY'),
          P_DOC_DATE_E: moment(this.params.INVOICE_DATE_TO, "DD-MM-YYYY").format('DD-MMM-YY'),
          P_CUST_S: this.params.CUSTOMER_CODE_FROM,
          P_CUST_E: this.params.CUSTOMER_CODE_TO,
          P_SENT_BY: this.params.SENT_BY
        })
      }
    } else {
      this.modal.warning('Please fill all data for print report!!', this.viewref)
    }
  }

  public SentByChange() {
    this.params.DSP_CUSTOMER_CODE_FROM = null;
    this.params.CUSTOMER_CODE_FROM = null;
    this.params.DSP_CUSTOMER_CODE_TO = null;
    this.params.CUSTOMER_CODE_TO = null;
    this.clearInput();
  }

  public CheckOriginChange(value) {
    if (value.checked == true) {
      this.params.CHK_PRN_MITH = 'Y'
    }
    else {
      this.params.CHK_PRN_MITH = 'N'
    }
  }

  public GenPaperless() {
    if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
      this.Http.post('SL', 'SNSE044N_Paperless', this.params)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'DONE') {
            this.modal.info('Done', this.viewref)
          }
        });
    } else {
      this.modal.warning('Please fill all data for Generate text file!!', this.viewref)
    }
  }

  public GenDragon() {
    if (this.params.CUSTOMER_CODE_FROM && this.params.CUSTOMER_CODE_TO && this.params.DOC_NO_FROM && this.params.DOC_NO_TO && this.params.INVOICE_DATE_FROM && this.params.INVOICE_DATE_TO) {
      this.Http.post('SL', 'SNSE044N_Dragon', this.params)
        .subscribe(res => {
          if (res.Table[0].STATUS == 'DONE') {
            this.modal.info('Done', this.viewref)
          }
        });
    } else {
      this.modal.warning('Please fill all data for Generate text file!!', this.viewref)
    }
  }
}
