import { Component, OnInit, ViewChild, ViewContainerRef } from "@angular/core";
import { HttpService } from 'src/app/core/http.service';
import { MatDialog } from '@angular/material/dialog';
import { DialogComponent } from '../../../components/shared/dialog/dialog.component';
import { ModalService } from '../../../core/modal.service';
import * as cloneDeep from 'lodash/cloneDeep';
import { Globals } from 'src/app/core/global';
import { ActivatedRoute } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { THIS_EXPR } from '@angular/compiler/src/output/output_ast';

@Component({
  selector: 'SNM054P',
    templateUrl: './SNM054P.component.html',
    styleUrls: ['./SNM054P.component.css']
})

export class SNM054PComponent implements OnInit {

  constructor(
    private http: HttpService,
    private modal: ModalService,
    private viewref: ViewContainerRef,
    private global: Globals,
    private route: ActivatedRoute
  ) {
  }

  @ViewChild("dialog", { static: false }) dialog: any;
  @ViewChild("DialogAdd", { static: false }) DialogAdd: any;
  @ViewChild("DialogEdit", { static: false }) DialogEdit: any;

  public tabledata = [];
  public paramAdd: any = {};
  public paramEdit: any = {};
  public paramSearch: any = {};
  public classNameEdit: any;
  public isAdd: boolean = false;

  public hideCols: Array<string> = [];
  DescriptCodeControl = new FormControl('', [Validators.required])

  public ConfigDiscountCode: any = {
    ColName: "DISCOUNT_CODE",
    ColValue: "",
    PlaceholderText: "Select Sales Class",
    SourceController: "TI",
    SourceMethodName: "SNM054P_Discount_Code",
    NoOfShowRecords: 20,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public SetDiscountCode(values: any) {
    this.paramSearch.DISCOUNT_CODE = values.DISCOUNT_CODE;
    this.paramSearch.DISCOUNT_NAME = values.DISCOUNT_NAME;
  }


  public Search() {
    this.tabledata = [];
    this.http.post("TI", "SNM054P_getSearch", this.paramSearch)
      .subscribe(res => {
        this.tabledata = res.Table;
      })
  }

  public EditRow(data) {
    this.DescriptCodeControl.reset();
    this.isAdd = false;
    this.paramEdit = data;
    this.DialogEdit.OpenDialog();
  }

  public Save() {
    this.modal.confirm("Do you want to save your change?", this.viewref,
      () => {
        this.http.post('TI', 'SNM054P_Save', this.paramEdit)
          .subscribe(res => {
            if (res.Table[0].STATUS === "Done") {
              this.modal.info('Save successfully', this.viewref)
              this.Search();
              this.DialogEdit.Close();
            }
          }, (err) => {
            console.log(err, 'err')
          })
      }, () => { })
  }

  public CancelEdit() {
    this.DialogEdit.Close();
  }

  public Add() {
    this.DescriptCodeControl.reset();
    this.paramAdd = {};
    this.isAdd = false
    this.DialogAdd.OpenDialog();
  }

  public SaveAdd() {
    this.modal.confirm("Do you want to save change you have made?", this.viewref, this.ConfirmSave);
  }

  public ConfirmSave = () => {
    console.log(this.paramAdd)
    this.http.post('TI', 'SNM054P_Insert', this.paramAdd)
      .subscribe(res => {

        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Transaction complete: applied and saved.', this.viewref);
          this.Search();
          this.paramAdd = this.global.ClearObject(this.paramAdd);
          this.DialogAdd.Close();

        } else if (res.Table[0].STATUS == 'Duplicate') {
          this.modal.warning('No change to save. Found duplicate record.', this.viewref);
        }
        else {
          this.modal.error('No change to save. Something went wrong.', this.viewref);
        }

      })
  }

  public CancelAdd() {
    this.DialogAdd.Close();
  }

  public Delete(data) {
    this.modal.confirm("Do you want to delete record?", this.viewref, () => this.ConfirmDelete(data))
  }

  public ConfirmDelete = data => {

    this.http.post('TI', 'SNM054P_Delete', data)
      .subscribe(res => {
        console.log(res);
        if (res.Table[0].STATUS == 'DONE') {
          this.modal.info('Delete completed: 1 record', this.viewref);
          this.Search();
        }
        else if (res.Table[0].STATUS == 'FAIL') {
          this.modal.warning(res.Table[0].MESSAGE, this.viewref);
        }
      })

  }

  ngOnInit() {
    this.Search();
  }
}
