import { SelectionModel } from '@angular/cdk/collections';
import { Component, OnInit, ViewContainerRef } from "@angular/core";
import { Globals } from 'src/app/core/global';
import { HttpService } from 'src/app/core/http.service';
import { ModalService } from 'src/app/core/modal.service';


@Component({
    selector: 'snm105p',
    templateUrl: './SNM105P.component.html',
    styleUrls: ['./SNM105P.component.css']
})

export class SNM105PComponent implements OnInit {

    constructor(
        private http: HttpService,
        private modal:ModalService,
        private viewref : ViewContainerRef,
        private global : Globals
    ) { }


    public CustomerList: any;
    public tableData: any = [];
    public files: any = [];
    public FileName: string = ""
    public selection = new SelectionModel<any>(true, []);
    public CheckBasePrice : boolean = true;
    public CheckStandardCost : boolean = true;
    ngOnInit() {

    }

    
    fileChange(fileInput) {
        this.selection.clear()
        this.files = fileInput.target.files;
        this.FileName = this.files[0].name;

        this.UpLoad()
    }

    UpLoad(){
        this.tableData = [];
        let formData = new FormData();
        formData.append('file', this.files[0]);

        this.http.postFile('TI', 'SNM105P_Upload', formData)
        .subscribe(res => {
          console.log('res',res)
          this.tableData = res.Table1;
         

        },(err) =>{
          this.modal.error("Upload error",this.viewref);
          //console.log('err',err)
        })
    }

    UpdatePrice(){
        this.modal.confirm("Do you want to save change you have made?",this.viewref,this.ConfirmUpdatePrice)
    }
    ConfirmUpdatePrice = () =>{
        let DataSave = []
        DataSave = this.selection.selected
        let isBasePrice = this.CheckBasePrice == true ? 'Y' : 'N';
        let isStandardCost = this.CheckStandardCost == true ? 'Y' : 'N';

        DataSave.map(x => {
            x.IS_BASE_PRICE = isBasePrice
            x.IS_STANDARD_COST = isStandardCost
        })
        this.http.post("TI","SNM105P_UpdatePrice",DataSave)
        .subscribe(res => {
            this.modal.info('Transaction complete: ' +  this.selection.selected.length  +' record applied and saved.', this.viewref);
        },(err)=>{
            this.modal.error('No change to save. Something went wrong.', this.viewref);
        })
    }


    DownLoad(){
        if(this.tableData.length == 0){
            this.modal.warning("No data for Export",this.viewref)
            return
        }


        this.http.Download("TI","SNM105P_Download",this.tableData)
        .subscribe(res =>{
            this.WriteContents(res)
        })
    }


    WriteContents(content) {

        const a = document.createElement('a');
        const file = new Blob([content], { type: content.type });
        a.href = URL.createObjectURL(file);
        a.download = "SNM105P" + '_' + this.global.CurrentDate() + ".csv";
        a.click();
      }

    isAllSelected() {
        const numSelected = this.selection.selected.length;
        const numRows = this.tableData.filter(x => x.ERR_FLAG == 'N').length;
        return numSelected === numRows;
      }
    
      Toggle() {
        this.isAllSelected() ?
          this.selection.clear() :
          this.tableData.forEach(row => {
            if (row.ERR_FLAG == 'N') {
              this.selection.select(row)
            }
          });
      }

      STDChange(event){
          let msg_err_stock = 'Does not exist on @TPM_STOCK_MASTER!'
          let msg_err_part = 'Does not exist on @TPM_PARTS_MASTER!'

          if(event.checked){
              this.tableData.map(x =>{
                  if(x.ERR_FLAG_PART == 'Y'){
                      x.MSG = msg_err_stock
                  }
              })
          }else{
              if(this.CheckBasePrice){                
                this.tableData.map(x =>{
                    if(x.ERR_FLAG_PART == 'Y'){
                        x.MSG = msg_err_part
                    }
                })
              }else{
                this.tableData.map(x =>{
                    if(x.ERR_FLAG_PART == 'Y'){
                        x.MSG = ""
                    }
                })
              }
          }

          this.tableData = this.tableData.slice();
          this.CheckSelect();
      }

      BPChange(event){
        let msg_err_stock = 'Does not exist on @TPM_STOCK_MASTER!'
        let msg_err_part = 'Does not exist on @TPM_PARTS_MASTER!'
          
        if(event.checked && !this.CheckStandardCost){
            this.tableData.map(x =>{
                if(x.ERR_FLAG_PART == 'Y'){
                    x.MSG = msg_err_part
                }
            })
        }else{
            if(this.CheckStandardCost){
              
              this.tableData.map(x =>{
                  if(x.ERR_FLAG_PART == 'Y'){
                      x.MSG = msg_err_stock
                  }
              })
            }else{
              this.tableData.map(x =>{
                  if(x.ERR_FLAG_PART == 'Y'){
                      x.MSG = ""
                  }
              })
            }
        }

        this.tableData = this.tableData.slice();
        this.CheckSelect();
    }


    CheckErr(){
        return this.tableData.filter(x => x.ERR_FLAG == 'N').length
    }

    CheckSelect(){
        if(!this.CheckBasePrice && !this.CheckStandardCost){
            this.selection.clear()
        }
    }


}
