import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { SelectionModel } from '@angular/cdk/collections';
import { Globals } from 'src/app/core/global';
@Component({
  selector: 'snm115p',
  templateUrl: './SNM115P.component.html',
  styleUrls: ['./SNM115P.component.css']
})



export class SNM115PComponent implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef,
    private global : Globals
  ) { }
  @ViewChild("dialog",{static: false}) dialog : any;
  @ViewChild("dialogIN",{static: false}) dialogIN : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tableData : any = [];
  public isAdd : boolean = false;
  public CategoryControl = new FormControl('',[Validators.required])
  public selection = new SelectionModel<any>(true,[]);
  public ERR_MSG : any = {}
  public tempData : any = {}
  public tempInactive : any = [];

  public ConfigCampaign: any = {
    ColName: "CAMPAIGN_ID",
    ColValue: "CAMPAIGN_ID",
    PlaceholderText: "Select Campaign ID",
    SourceController: "TI",
    SourceMethodName: "SNM115P_CampaignID",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false
  }


  ngOnInit() {
    this.ParamSearch.STATUS = 'ALL'
  }

  Search(){
    this.selection.clear()
    this.tableData = []
    this.http.post("TI","SNM115P_CampaignList",this.ParamSearch)
    .subscribe(res =>{
          this.tableData = res.Table
    })

  }

  Active(){
    if(this.TotalInactive() == 0){
      this.modal.warning("To active campaign please select 1 inactive record!",this.viewref)
      return;
    }

    if(this.TotalInactive() > 1){
      this.modal.warning("You can active 1 record per 1 time!",this.viewref)
      return;
    }

    this.modal.confirm("Do you want to active this campaign?",this.viewref,() =>{
      this.tempData = {};
      let findItem = this.selection.selected.find(x => x.STATUS == 'N')
      this.tempData = findItem;

      this.http.post('TI','SNM115P_Active',findItem)
      .subscribe(res =>{
        this.ERR_MSG = res
        this.dialog.OpenDialog()
        if(this.ERR_MSG.N_FLAG_RESULT == 'COMPLETE'){
          this.Search()
        }
        //this.Search()
        console.log('errrrr',this.ERR_MSG)
      })
    })

 
  }

  Inactive(){
    if(this.TotalActive() == 0){
      this.modal.warning("To inactive campaign please select atleast 1 active record!",this.viewref)
      return;
    }


    this.modal.confirm("Do you want to inactive " + this.TotalActive() + " record(s)?",this.viewref,() =>{

      this.tempInactive = [];
      this.tempInactive = this.selection.selected.filter(x => x.STATUS == 'Y')
      this.http.post('TI',"SNM115P_Inactive",this.tempInactive)
      .subscribe(res =>{
        this.dialogIN.OpenDialog()
        this.Search()
      })
    })

  }

  DownLoad(data){
    this.http.Download("TI","SNM115P_DownLoad",data)
    .subscribe(res =>{
      this.WriteContents(res,data)
    })
  }

  WriteContents(content,data) {

    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNM105P_" + data.CAMPAIGN_ID +  "-" + this.FormatDate() + ".slk";
    a.click();
  }



  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.tableData.length;
    return numSelected === numRows;
  }

  Toggle() {
    this.isAllSelected() ?
      this.selection.clear() :
      this.tableData.forEach(row => this.selection.select(row));
  }


  TotalActive(){
    return this.selection.selected.filter(x => x.STATUS == 'Y').length
  }

  TotalInactive(){
    return this.selection.selected.filter(x => x.STATUS == 'N').length
  }

  FormatDate(){
    let d = new Date();
    let Day = d.getDate().toString();
    let Month = d.getMonth() + 1;
    let NewMonth = Month.toString().length < 2 ? '0' + Month.toString() : Month.toString()
    let Year = d.getFullYear().toString();
    return Year + NewMonth + Day;
  }

  
}
