import { Component, OnInit, Input, Output, EventEmitter, TemplateRef, ContentChild, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router, ActivatedRoute } from '@angular/router';
import { Globals } from 'src/app/core/global';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';

@Component({
  selector: 'snse165',
  templateUrl: './snse165.component.html',
  styleUrls: ['./snse165.component.css']
})



export class SNSE165Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private route: ActivatedRoute,
    private global: Globals,
    private modal :ModalService,
    private ViewRef : ViewContainerRef
  ) { 

  }

  public ConfigBuyer: any = {
    ColName: "BUYER_CODE",
    ColValue: "BUYER_CODE",
    PlaceholderText: "Select Buyer Code",
    SourceController: "TI",
    SourceMethodName: "SNSE165_GetBuyer",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: true
  }

  public dataList: any = [];
  public CustomerList: any = [];
  public params : any = {};
  public selection = new SelectionModel<any>(true, []);
  public paramsYM : any = {};
  @ViewChild("dialogYearMonth", { static: false }) dialogYearMonth: any;
  ngOnInit() {
    var date = new Date();
    var firstDay = new Date(date.getFullYear(), date.getMonth(), 2);
    this.params.FROM_DATE = firstDay
    this.params.TO_DATE = date
    this.params.RECORD_STATUS = 'ALL'
  }


  Search(){
    this.selection.clear();
    //console.log(this.params)
    this.http.post("TI","SNSE165_Search",this.params)
    .subscribe(res => {
      console.log(res)
      this.dataList = res.Table ;
      this.FirstSelect();
    })
  }

  FirstSelect(){
    if(this.params.RECORD_STATUS != 'N' && this.params.RECORD_STATUS != 'R'){
      this.dataList.forEach(row => {
        if(row.UPDATE_STATUS != 'N' && row.UPDATE_STATUS != 'R'){
          this.selection.select(row)
        }
       
      })
    }
  }


  isAllSelected() {
    const numSelected = this.selection.selected.length;
    const numRows = this.dataList.length;
    //const numRows = this.dataList.filter(x => !x.ERR_MASSAGE).length;
    return numSelected === numRows;
  }

  Toggle() {
    this.isAllSelected() ? this.selection.clear() : this.dataList.forEach(row => this.selection.select(row));
      // this.dataList.forEach(row => {
      //   if (!row.ERR_MASSAGE) {
      //     this.selection.select(row)
      //   }
      // });
  }

  ProcessPrice(){
    this.paramsYM = {};
    this.dialogYearMonth.OpenDialog()
  }

  UpdatePriceList(){

    if(!this.paramsYM.YEAR && !this.paramsYM.MONTH){
      this.modal.warning("Please input year and month",this.ViewRef)
      return;
    }

    if(this.paramsYM.MONTH > 12){
      this.modal.error("Month cannot be greater than 12",this.ViewRef)
      return;
    }

    if(this.selection.selected.length == 0){
      this.modal.warning("Please select data for process",this.ViewRef)
      return;
    }


    this.modal.confirm("Do you want to save change you have made?",this.ViewRef,this.ConfirmUpdatePriceList)

    
  }

  ConfirmUpdatePriceList = () => {
    this.selection.selected.map(x => {
      x.YEAR = this.paramsYM.YEAR 
      x.MONTH = this.paramsYM.MONTH
    })

    let DataSave = []
    DataSave = this.selection.selected
    this.http.post('TI','SNSE165_UPdatePrice_list',DataSave)
    .subscribe(res =>{
      this.modal.info("Process Complete",this.ViewRef);
      this.dialogYearMonth.Close();
      this.Search();
      
    },(err) =>{
      console.log(err)
      this.modal.error("Found an error, please contract support team", this.ViewRef);
    })
  }

  CancelProcessPrice(){
    
    this.dialogYearMonth.Close();
  }

  ReUpdate(){

    if(this.selection.selected.length == 0){
      this.modal.warning("Please select data for process",this.ViewRef)
      return;
    }

    this.modal.confirm("Do you want to save change you have made?",this.ViewRef,this.COnfirmReUpdate)
  }

  COnfirmReUpdate =()=>{

    this.http.post('TI','SNSE165_ReUpdate',this.selection.selected)
    .subscribe(res =>{
      this.modal.info("Process Complete",this.ViewRef);
      this.Search();
        //console.log('res',res)
    },(err) => {
      console.log(err)
      this.modal.error("Found an error, please contract support team", this.ViewRef);
    })

  }


  CancelRecord(){

    if(this.selection.selected.length == 0){
      this.modal.warning("Please select data for process",this.ViewRef)
      return;
    }

    this.modal.confirm("Do you want to save change you have made?",this.ViewRef,this.ConfirmCancelRecord)
  }

  ConfirmCancelRecord = ()=>{
    this.http.post('TI','SNSE165_CancelPrice',this.selection.selected)
    .subscribe(res =>{
      this.modal.info("Process Complete",this.ViewRef);
      this.Search();
    },(err)=>{
      console.log(err)
      this.modal.error("Found an error, please contract support team", this.ViewRef);
    })
  }

  Export() {

    let DataForExport = []
    DataForExport = this.dataList.filter(x => x.PART_NUMBER)

    if(DataForExport.length == 0){
      this.modal.warning("No data for export",this.ViewRef)
      return;
    }

    
    this.http.Download('TI', 'SNSE165_Export', DataForExport)
        .subscribe(res => {
            if (res) {
              this.writeContents(res)     
              this.modal.info("Download Complete",this.ViewRef)         
            } else {
                this.modal.error('Download Not Complete', this.ViewRef)
            }

        })

  }

  writeContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSE165" + '-' + this.global.CurrentDate() + '' + ".csv";
    a.click();
  }

}



