import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { FormControl, Validators } from '@angular/forms';
import { ModalService } from 'src/app/core/modal.service';
import { Globals } from 'src/app/core/global';
import { min } from 'rxjs/operators';

@Component({
  selector: 'snsq032',
  templateUrl: './SNSQ032.component.html',
  styleUrls: ['./SNSQ032.component.css']
})



export class SNSQ032Component implements OnInit {


  constructor(
    private http: HttpService,
    private router: Router,
    private modal : ModalService,
    private viewref : ViewContainerRef,
    private global : Globals
  ) { }
  @ViewChild("dialog",{static: false}) dialog : any;
  public ParamSearch :any ={};
  public Params :any ={};
  public categoryList: any = [];
  public tabledata : any = [];
  public isAdd : boolean = false;
  public CategoryControl = new FormControl('',[Validators.required])

  public ConfigProcessGroup: any = {
    ColName: "PROCESS_GROUP",
    ColValue: "",
    PlaceholderText: "Select Process Group",
    SourceController: "TI",
    SourceMethodName: "SNSQ032_ProcessGroup",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      SYSTEM_GROUP : null
    },
  }


  public ConfigProcessName: any = {
    ColName: "PROCESS_NAME",
    ColValue: "",
    PlaceholderText: "Select Process Name",
    SourceController: "TI",
    SourceMethodName: "SNSQ032_ProcessName",
    NoOfShowRecords: 50,
    MinLengthSearch: 0,
    UpperCase: false,
    SourceParams: {
      SYSTEM_GROUP : null,
      PROCESS_GROUP : null
    },
  }


  public tblFooter: any = [
    {
      fieldName: "SEQ",
      value: null,
      show: true
    },]


  ngOnInit() {
   
    this.ParamSearch.SYSTEM_GROUP = 'MPS'
    this.ParamSearch.PROCESS_GROUP = 'ALL'
    this.ParamSearch.PROCESS_NAME = 'ALL'
    this.ParamSearch.RECEIVED_STATUS = 'N'
    this.ParamSearch.DATE_FROM = this.FirstDateOfMonth();
    this.ParamSearch.DATE_TO = new Date();
    this.ParamSearch.PROCESS_GROUP_SHOW = 'All'
    this.ParamSearch.PROCESS_NAME_SHOW = 'All'
    this.ConfigProcessGroup.SourceParams.SYSTEM_GROUP = 'MPS'
    this.ConfigProcessName.SourceParams.SYSTEM_GROUP = 'MPS'
    this.ConfigProcessName.SourceParams.PROCESS_GROUP = 'ALL'
  }

  Search(){
    this.tabledata = []
    this.http.post("TI","SNSQ032_GetData",this.ParamSearch)
    .subscribe(res =>{
      if(res.Table.length > 0 ){
        res.Table.map((x,i) => {
          x.SEQ = i + 1
        })
        this.tblFooter[0].value = "Count Item : " + res.Table.length.toLocaleString()
        this.tabledata = res.Table
      }else{
        this.tabledata = res.Table
      }
          
    })
  }

  SystemChange(event){
    this.ConfigProcessGroup.SourceParams.SYSTEM_GROUP = event
    this.ConfigProcessName.SourceParams.SYSTEM_GROUP = event
    //this.ConfigProcessName.SourceParams.PROCESS_GROUP = 'ALL'
  }


  ExportExcel(){
    if(this.tabledata.length == 0){
      this.modal.warning("No data for export!",this.viewref);
    }else{

      this.http.Download("TI","SNSQ032_Download",this.tabledata)
      .subscribe(res =>{
        this.modal.info("Export Complete",this.viewref);
        this.writeContents(res)
      })


    }
  }

  writeContents(content) {
    const a = document.createElement('a');
    const file = new Blob([content], { type: content.type });
    a.href = URL.createObjectURL(file);
    a.download = "SNSQ032_FILE" + '-' + this.FormateDate() + '' + ".csv";
    a.click();
  }


  FormateDate() {

    let d = new Date()
    let day = d.getDate();
    let newDay = day.toString().length < 2 ? 0 + '' + day.toString() : day.toString();
    let m = d.getMonth() + 1;
    let newMonth = m.toString().length < 2 ? 0 + '' + m.toString() : m.toString();
    let y = d.getFullYear();
    let hours = d.getHours();
    let minute = d.getMinutes();
    let seconds = d.getSeconds();
    return y + '' + newMonth + '' + newDay + '_' + hours + ':' + minute + ':' + seconds;
}

  FirstDateOfMonth(){
  var date = new Date();
  var firstDay = new Date(date.getFullYear(), date.getMonth(), 1);
  firstDay.setDate(firstDay.getDate() + 1);
  return firstDay;
}


}
