import { Component, OnInit, ViewChild, ViewContainerRef } from '@angular/core';
import { HttpService } from 'src/app/core/http.service';
import { Router } from '@angular/router';
import { SelectionModel } from '@angular/cdk/collections';
import { ModalService } from 'src/app/core/modal.service';

@Component({
    selector: 'snm108p',
    templateUrl: './SNM108P.component.html',
    styleUrls: ['./SNM108P.component.css']
})



export class SNM108PComponent implements OnInit {


    constructor(
        private http: HttpService,
        private router: Router,
        private modal : ModalService,
        private viewref : ViewContainerRef
    ) { }

    @ViewChild("dialogAdd",{static : false}) dialogAdd : any;
    @ViewChild("dialogEdit",{static : false}) dialogEdit : any;

    public selection = new SelectionModel<any>(true,[]);
    public data: any;
    public valid : boolean = false;
    public Param = {
        CUSTOMER_CODE : null,
        HUB_CODE : null
       
    }

    public AddData = {
        CUSTOMER_CODE_LOOKUP : '',
        HUB_CODE : null,
        CUSTOMER_BRANCH_NAME : null,
        CUSTOMER_CODE : null,
        BRANCH_CODE : null
    }

    
    public ConfigCustomer: any = {
        ColName: "CODE_NAME",
        ColValue: "CUSTOMER_CODE",
        PlaceholderText: "Select Customer",
        SourceController: "wPMS",
        SourceMethodName: "GetCustomerCode",
        NoOfShowRecords: 25,
        MinLengthSearch : 3,
        UpperCase : true
    }

    
    public ConfigHubCode: any = {
        ColName: "HUB_CODE",
        ColValue: "HUB_CODE",
        PlaceholderText: "Select HubCode",
        SourceController: "wPMS",
        SourceMethodName: "GetHubCode",
        NoOfShowRecords: 20,
        MinLengthSearch : 1,
        UpperCase : true
    }

    public ConfigCustomerAdd: any = {
        ColName: "LOOKUP_NAME",
        ColValue: "",
        PlaceholderText: "Select Customer",
        SourceController: "WH",
        SourceMethodName: "GetCustomerAddHub",
        NoOfShowRecords: 50,
        MinLengthSearch : 3,
        UpperCase : true
    }

    public EditData = {
        CUSTOMER_CODE_LOOKUP : '',
        HUB_CODE : null,
        CUSTOMER_BRANCH_NAME : null,
        CUSTOMER_CODE : null,
        BRANCH_CODE : null
    }


    ngOnInit() {
   

    }

    Search(){

        if(!this.Param.CUSTOMER_CODE && !this.Param.HUB_CODE){
            this.modal.warning('Please input either [Customer Code] or [Hub Code]',this.viewref)
        }else{
          this.GetData();
        }
    }

    GetData(){
        
        this.data = [];
        this.Param.CUSTOMER_CODE = !this.Param.CUSTOMER_CODE  ? null : this.Param.CUSTOMER_CODE.toUpperCase();
        this.Param.HUB_CODE = !this.Param.HUB_CODE ? null : this.Param.HUB_CODE.toUpperCase();
        this.http.post("WH","SNM108P_GetData",this.Param)
        .subscribe(res =>{
            
            this.data = res.Table;
            console.log(this.data)
        })
    }

    SelectedCustomerAdd(event){
        this.AddData.CUSTOMER_CODE_LOOKUP = event.CUS_CODE;
        this.AddData.CUSTOMER_BRANCH_NAME = event.CUS_NAME;
        this.AddData.CUSTOMER_CODE = event.CUSTOMER_CODE;
        this.AddData.BRANCH_CODE = event.BRANCH_CODE;
        this.valid = true
        console.log(event)
    }

    ValidateCustomer(){
        if(this.AddData.CUSTOMER_CODE_LOOKUP.length != 0 && this.AddData.CUSTOMER_CODE_LOOKUP.length < 3){
            this.modal.warning('no data found',this.viewref)
        }else{

            let Customer_Code = this.AddData.CUSTOMER_CODE_LOOKUP.substring(0,this.AddData.CUSTOMER_CODE_LOOKUP.length - 2)
            let Branch_Code = this.AddData.CUSTOMER_CODE_LOOKUP.substring(this.AddData.CUSTOMER_CODE_LOOKUP.length - 2,this.AddData.CUSTOMER_CODE_LOOKUP.length)

            this.http.get('WH','SNM108P_Validate',Customer_Code.toUpperCase(),Branch_Code.toUpperCase())
            .subscribe(res => {

                if(res.Table.length == 0){

                    this.modal.warning('no data found',this.viewref)
                    this.valid = false;
                    this.AddData.CUSTOMER_BRANCH_NAME = ''
                    this.AddData.HUB_CODE = ''
                }else{

                    this.AddData.CUSTOMER_BRANCH_NAME = res.Table[0].CUS_NAME;
                    this.AddData.CUSTOMER_CODE = res.Table[0].CUSTOMER_CODE;
                    this.AddData.BRANCH_CODE = res.Table[0].BRANCH_CODE;
                    this.valid = true
                }
               
                console.log(res)
            })
        }
    }


    SaveAdd() {

        this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveAdd)

    }

    ConfirmSaveAdd = () => {

        this.AddData.HUB_CODE = !this.AddData.HUB_CODE ? null : this.AddData.HUB_CODE.toUpperCase();

        this.http.post('WH', 'SNM108P_Insert', this.AddData)
            .subscribe(res => {
                if (res.Table[0].STATUS == 'DONE') {
                    this.modal.info('Transaction complete: applied and saved.', this.viewref);   
                    this.dialogAdd.Close();
                    this.AddData.CUSTOMER_BRANCH_NAME = null;
                    this.AddData.CUSTOMER_CODE = null;
                    this.AddData.BRANCH_CODE = null;    
                    this.AddData.CUSTOMER_CODE_LOOKUP = '';           
                                               
                } else {
                    this.modal.info('No change to save. Something went wrong.', this.viewref);
                }

            })             
}

CancelAdd(){
    this.dialogAdd.Close();
}


Edit(data){
    this.EditData.CUSTOMER_CODE = data.CUSTOMER_CODE;
    this.EditData.BRANCH_CODE = data.BRANCH_CODE;
    this.EditData.HUB_CODE = data.HUB_CODE;
    this.EditData.CUSTOMER_CODE_LOOKUP = data.CUS_BRANCH;
    this.EditData.CUSTOMER_BRANCH_NAME = data.BRANCH_NAME_EN
    this.dialogEdit.OpenDialog();
    console.log(data)
}


SaveEdit() {
    this.modal.confirm('Do you want to save changed you have made?', this.viewref, this.ConfirmSaveEdit)

}

ConfirmSaveEdit = () => {

    this.EditData.HUB_CODE = !this.EditData.HUB_CODE ? null : this.EditData.HUB_CODE.toUpperCase();

    this.http.post('WH', 'SNM108P_Update', this.EditData)
        .subscribe(res => {
            if (res.Table[0].STATUS == 'DONE') {
                this.modal.info('Transaction complete: applied and saved.', this.viewref);   
                this.dialogEdit.Close();
                this.GetData()         
                                           
            } else {
                this.modal.info('No change to save. Something went wrong.', this.viewref);
            }

        })             
}

    CancelEdit(){
        this.dialogEdit.Close();
    }

    Delete() {

        this.modal.confirm('Do you want to delete record?', this.viewref, this.ConfirmDelete)
    }

    ConfirmDelete = () => {

        //this.data.splice(this.index, 1)
        //this.data = this.data.slice();
    this.http.post('WH', 'SNM108P_Delete',this.selection.selected)
            .subscribe(res => {
                console.log(res)
                if (res == 'DONE') {
                    this.modal.info('Transaction complete:' + ' ' + this.selection.selected.length + ' ' + 'record applied and saved.', this.viewref);    
                    this.selection.clear();
                    this.GetData();
                    
                } else {
                    this.modal.warning('No change to save. Something went wrong.', this.viewref);
                }
            })
    }

}

